@@ -23,7 +23,7 @@ rm -rf usr/
 ../../ci/docker-run.sh "$rust_stable_docker_image" \
   scripts/cargo-install-all.sh sdk/docker-solana/usr
 
-cp -f ../../run.sh usr/bin/solana-run.sh
+cp -f ../../scripts/run.sh usr/bin/solana-run.sh
 cp -f ../../fetch-spl.sh usr/bin/
 (
   cd usr/bin
